package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;

import java.util.TimerTask;

public class SlowCooking010D extends BaseDevMode {

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;

    private boolean autoPasue = false;


    private  boolean isMotorType = false;

    public SlowCooking010D() {

        this.setMode(WorkModes.SLOW_COOKING);


        //时间
        this.setMinTime(10 * 60);
        this.setMaxTime(90 * 60);
        this.setDefaultTime(60 * 60);
        this.setTimeChange(true);

        //电机
        this.setDefaultMotorGear(1);
        this.setMaxMotorGear(3);
        this.setMinMotorGear(1);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(true);
        this.setMotorDirection(MotorDirections.FORWARD);

        //温度
        this.setDefaultTemp(100);
        this.setMinTemp(60);
        this.setMaxTemp(100);

        this.setDiyCountDown(true);

    }


    @Override
    public void start() {
        currentSec = 0L;
        this.pasue = false;
        this.setIsStartMotorGear( CofarSDK.devInfo().getMotorGear());
        this.setMotorGearChange(false);
        CofarSDK.startNative();
        this.stop = false;

    }



    @Override
    public void onCountDown(TimerTask timer) {
        if (!pasue && DevStatus.PAUSE == CofarSDK.devInfo().getStatus()) {
            if (!autoPasue) {
                return;
            }
        }

        if (pasue) {
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();

        /**
         * 在调试试过由于resume的方法，可能没法实时同步转速
         * 在停25的逻辑中在点击暂停的时候设置转速
         * 点击resume按钮回调到resume方法，有可能会导致motorGearBuffer=-1，motorGear=0
         * 估在这写在motorGearBuffer不等于=-1 任何情况下 转速值重新写
         *  后面改了获取getMotorGear ，
         * */
        if (CofarSDK.devInfo().getMotorGear()!=0){
            this.setIsStartMotorGear(devInfo.getMotorGear());
        }

        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown()) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));


//        if (((currentSec / 5) % 6) == 1) {
//            autoPasue=true;
//            CofarSDK.pauseNatvie();
//        }
//
//        if (((currentSec / 5) % 6) == 0) {
//            autoPasue=false;
//            CofarSDK.resumeNavtive();
//        }


        if (((currentSec / 5) % 6) == 1) {
            autoPasue=true;

            if (isMotorType){
                CofarSDK.cfgMotorGearNative((byte)0);
                isMotorType = false;
            }


        }

        if (((currentSec / 5) % 6) == 0) {
            autoPasue=false;

            if (!isMotorType){
                CofarSDK.cfgMotorGearNative((byte) getIsStartMotorGear());
                isMotorType = true;
            }
        }


        currentSec++;

    }

    @Override
    public void pause() {
        this.pasue = true;
        this.setMotorGearChange(true);
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        this.setMotorGearChange(false);
        /**
         * 重新设置挡速有问题，估resume重新开5停25
         * **/
        currentSec = 0L;
        CofarSDK.resumeNavtive();


    }

    @Override
    public void stop() {
        this.stop = true;
        this.setMotorGearChange(true);
        CofarSDK.stopNative();
        CofarSDK.cfgMotorGearNative((byte) 1);
        super.stop();
    }


}
